@@ -14,12 +14,14 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
 */
 
 #ifndef __LIBGCMD_WIDGET_FACTORY_H__
 #define __LIBGCMD_WIDGET_FACTORY_H__
 
+G_BEGIN_DECLS
+
 GtkWidget *
 lookup_widget (GtkWidget *widget, const gchar *widget_name);
 
@@ -169,4 +171,6 @@ create_error_dialog (const gchar *msg, ...);
 void
 create_warning_dialog (const gchar *msg, ...);
 
+G_END_DECLS
+
 #endif //__LIBGCMD_WIDGET_FACTORY_H__
