@@ -290,7 +290,7 @@ create_ftp_server_dialog (const gchar *title,
     const gchar *labels2[] = {_("Host:"), _("Port:"), _("User:"), _("Password:"), _("Remote Dir:")};
 
     const gchar **labels = with_alias ? labels1 : labels2;
-    const guint labels_size = with_alias ? sizeof(labels1)/sizeof(gchar *) : sizeof(labels2)/sizeof(gchar *);
+    const guint labels_size = with_alias ? ARRAY_ELEMENTS(labels1) : ARRAY_ELEMENTS(labels2);
 
     GtkWidget *dialog;
     GtkWidget *pw_entry;
@@ -510,7 +510,7 @@ init (GnomeCmdFtpDialog *ftp_dialog)
     gtk_clist_set_row_height (GTK_CLIST (ftp_dialog->priv->server_list), 16);
     gtk_widget_show (ftp_dialog->priv->server_list);
     gtk_container_add (GTK_CONTAINER (sw), ftp_dialog->priv->server_list);
-    gtk_widget_set_usize (ftp_dialog->priv->server_list, -1, 200);
+    gtk_widget_set_size_request (ftp_dialog->priv->server_list, -1, 200);
     gtk_clist_set_column_width (GTK_CLIST (ftp_dialog->priv->server_list), 0, 16);
     gtk_clist_set_column_width (GTK_CLIST (ftp_dialog->priv->server_list), 1, 80);
     gtk_clist_column_titles_show (GTK_CLIST (ftp_dialog->priv->server_list));
