@@ -1,6 +1,6 @@
 /*
-    GNOME Commander - A GNOME based file manager 
-    Copyright (C) 2001-2004 Marcus Bjurman
+    GNOME Commander - A GNOME based file manager
+    Copyright (C) 2001-2006 Marcus Bjurman
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -14,26 +14,28 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-*/ 
+    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
+*/
+
 #ifndef __GNOME_CMD_SMB_NET_H__
 #define __GNOME_CMD_SMB_NET_H__
 
+G_BEGIN_DECLS
 
 typedef enum
 {
-	SMB_WORKGROUP,
-	SMB_HOST
+    SMB_WORKGROUP,
+    SMB_HOST
 } SmbEntityType;
 
 
 typedef struct
 {
-	gchar *name;
-	SmbEntityType type;
+    gchar *name;
+    SmbEntityType type;
 
-	// this one is only set if type == SMB_HOST and
-	gchar *workgroup_name;
+    // this one is only set if type == SMB_HOST and
+    gchar *workgroup_name;
 } SmbEntity;
 
 
@@ -41,7 +43,6 @@ typedef struct
 SmbEntity *
 gnome_cmd_smb_net_get_entity (const gchar *name);
 
+G_END_DECLS
 
-#endif //__GNOME_CMD_SMB_NET_H__
-
-
+#endif // __GNOME_CMD_SMB_NET_H__
